@@ -1,21 +1,8 @@
 /*
-  Copyright (c) 2010 Bertjan Broeksema <broeksema@kde.org>
-  Copyright (C) 2010 Klaralvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
+  SPDX-FileCopyrightText: 2010 Bertjan Broeksema <broeksema@kde.org>
+  SPDX-FileCopyrightText: 2010 Klaralvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "alarmdialog.h"
@@ -34,11 +21,9 @@ AlarmDialog::AlarmDialog(KCalendarCore::Incidence::IncidenceType incidenceType,
     : QDialog(parent)
     , mUi(new Ui::AlarmDialog)
     , mIncidenceType(incidenceType)
-    , mAllowBeginReminders(true)
-    , mAllowEndReminders(true)
 {
     setWindowTitle(i18nc("@title:window", "Create a new reminder"));
-    QVBoxLayout *mainLayout = new QVBoxLayout(this);
+    auto *mainLayout = new QVBoxLayout(this);
     QDialogButtonBox *buttonBox = new QDialogButtonBox(
         QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
     QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
@@ -246,7 +231,7 @@ void AlarmDialog::fillCombo()
             items << i18n("Before the to-do is due") << i18n("After the to-do is due");
         }
     } else {
-        if (mAllowEndReminders) {
+        if (mAllowBeginReminders) {
             items << i18n("Before the event starts") << i18n("After the event starts");
         }
         if (mAllowEndReminders) {
