@@ -1,27 +1,11 @@
 /*
-  Copyright (c) 2003 Cornelius Schumacher <schumacher@kde.org>
-  Copyright (C) 2005 Reinhold Kainhofer <reinhold@kainhofer.com>
-  Copyright (c) 2005 Rafal Rzepecki <divide@users.sourceforge.net>
-  Copyright (c) 2010 Bertjan Broeksema <broeksema@kde.org>
-  Copyright (C) 2010 Klaralvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
+  SPDX-FileCopyrightText: 2003 Cornelius Schumacher <schumacher@kde.org>
+  SPDX-FileCopyrightText: 2005 Reinhold Kainhofer <reinhold@kainhofer.com>
+  SPDX-FileCopyrightText: 2005 Rafal Rzepecki <divide@users.sourceforge.net>
+  SPDX-FileCopyrightText: 2010 Bertjan Broeksema <broeksema@kde.org>
+  SPDX-FileCopyrightText: 2010 Klaralvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 
   NOTE: May, 2010. Extracted this code from
         kdepim/incidenceeditors/editorattachments.{h,cpp}
@@ -30,7 +14,7 @@
 #ifndef INCIDENCEEDITOR_ATTACHMENTICONVIEW_H
 #define INCIDENCEEDITOR_ATTACHMENTICONVIEW_H
 
-#include <KCalCore/Attachment>
+#include <KCalendarCore/Attachment>
 
 #include <QMimeType>
 #include <QUrl>
@@ -56,10 +40,10 @@ protected:
 class AttachmentIconItem : public QListWidgetItem
 {
 public:
-    AttachmentIconItem(const KCalCore::Attachment &att, QListWidget *parent);
+    AttachmentIconItem(const KCalendarCore::Attachment &att, QListWidget *parent);
     ~AttachmentIconItem();
 
-    KCalCore::Attachment attachment() const;
+    Q_REQUIRED_RESULT KCalendarCore::Attachment attachment() const;
     Q_REQUIRED_RESULT const QString uri() const;
     Q_REQUIRED_RESULT const QString savedUri() const;
     void setUri(const QString &uri);
@@ -84,7 +68,7 @@ public:
     Q_REQUIRED_RESULT QUrl tempFileForAttachment();
 
 private:
-    KCalCore::Attachment mAttachment;
+    KCalendarCore::Attachment mAttachment;
     QString mSaveUri;
     QUrl mTempFile;
 };
