@@ -1,23 +1,7 @@
 /*
- * Copyright (c) 2014 Sandro Knauß <knauss@kolabsys.com>
+ * SPDX-FileCopyrightText: 2014 Sandro Knauß <knauss@kolabsys.com>
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License along
- * with this program; if not, write to the Free Software Foundation, Inc.,
- * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
- *
- * As a special exception, permission is given to link this program
- * with any edition of Qt, and distribute the resulting executable,
- * without including the source code for Qt in the source distribution.
+ * SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
  */
 
 #include "attendeecomboboxdelegate.h"
@@ -35,9 +19,9 @@ using namespace IncidenceEditorNG;
 
 AttendeeComboBoxDelegate::AttendeeComboBoxDelegate(QObject *parent)
     : QStyledItemDelegate(parent)
-    , mStandardIndex(0)
 {
-    connect(this, &AttendeeComboBoxDelegate::closeEditor, this, &AttendeeComboBoxDelegate::doCloseEditor);
+    connect(this, &AttendeeComboBoxDelegate::closeEditor, this,
+            &AttendeeComboBoxDelegate::doCloseEditor);
 }
 
 void AttendeeComboBoxDelegate::addItem(const QIcon &icon, const QString &text)
@@ -68,12 +52,11 @@ void AttendeeComboBoxDelegate::setStandardIndex(int index)
     mStandardIndex = index;
 }
 
-QWidget *AttendeeComboBoxDelegate::createEditor(QWidget *parent, const QStyleOptionViewItem &/* option */, const QModelIndex &/* index */) const
+QWidget *AttendeeComboBoxDelegate::createEditor(QWidget *parent, const QStyleOptionViewItem & /* option */, const QModelIndex & /* index */) const
 {
-    AttendeeComboBox *editor = new AttendeeComboBox(parent);
-    QPair<QIcon, QString> pair;
+    auto *editor = new AttendeeComboBox(parent);
 
-    foreach (pair, mEntries) {
+    for (const QPair<QIcon, QString> &pair : qAsConst(mEntries)) {
         editor->addItem(pair.first, pair.second);
     }
 
@@ -88,7 +71,7 @@ QWidget *AttendeeComboBoxDelegate::createEditor(QWidget *parent, const QStyleOpt
 
 void AttendeeComboBoxDelegate::setEditorData(QWidget *editor, const QModelIndex &index) const
 {
-    AttendeeComboBox *comboBox = static_cast<AttendeeComboBox *>(editor);
+    auto *comboBox = static_cast<AttendeeComboBox *>(editor);
     int value = index.model()->data(index, Qt::EditRole).toUInt();
     if (value >= mEntries.count()) {
         value = mStandardIndex;
@@ -98,19 +81,19 @@ void AttendeeComboBoxDelegate::setEditorData(QWidget *editor, const QModelIndex
 
 void AttendeeComboBoxDelegate::setModelData(QWidget *editor, QAbstractItemModel *model, const QModelIndex &index) const
 {
-    AttendeeComboBox *comboBox = static_cast<AttendeeComboBox *>(editor);
+    auto *comboBox = static_cast<AttendeeComboBox *>(editor);
     model->setData(index, comboBox->currentIndex(), Qt::EditRole);
     comboBox->menu()->close();
 }
 
-void AttendeeComboBoxDelegate::updateEditorGeometry(QWidget *editor, const QStyleOptionViewItem &option, const QModelIndex &/* index */) const
+void AttendeeComboBoxDelegate::updateEditorGeometry(QWidget *editor, const QStyleOptionViewItem &option, const QModelIndex & /* index */) const
 {
     editor->setGeometry(option.rect);
 }
 
 void AttendeeComboBoxDelegate::paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const
 {
-    QStyleOptionButton myOption;;
+    QStyleOptionButton myOption;
 
     int value = index.model()->data(index).toUInt();
     if (value >= mEntries.count()) {
@@ -120,6 +103,7 @@ void AttendeeComboBoxDelegate::paint(QPainter *painter, const QStyleOptionViewIt
     myOption.rect = option.rect;
     myOption.state = option.state;
     myOption.icon = mEntries[value].first;
+    myOption.iconSize = myOption.icon.actualSize(option.rect.size());
 
     QApplication::style()->drawControl(QStyle::CE_PushButton, &myOption, painter);
 }
@@ -127,7 +111,7 @@ void AttendeeComboBoxDelegate::paint(QPainter *painter, const QStyleOptionViewIt
 bool AttendeeComboBoxDelegate::eventFilter(QObject *editor, QEvent *event)
 {
     if (event->type() == QEvent::Enter) {
-        AttendeeComboBox *comboBox = static_cast<AttendeeComboBox *>(editor);
+        auto *comboBox = static_cast<AttendeeComboBox *>(editor);
         comboBox->showMenu();
         return editor->eventFilter(editor, event);
     }
@@ -137,40 +121,41 @@ bool AttendeeComboBoxDelegate::eventFilter(QObject *editor, QEvent *event)
 
 void AttendeeComboBoxDelegate::doCloseEditor(QWidget *editor)
 {
-    AttendeeComboBox *comboBox = static_cast<AttendeeComboBox *>(editor);
+    auto *comboBox = static_cast<AttendeeComboBox *>(editor);
     comboBox->menu()->close();
 }
 
 void AttendeeComboBoxDelegate::leftPressed()
 {
-    Q_EMIT closeEditor(static_cast<QWidget *>(QObject::sender()), QAbstractItemDelegate::EditPreviousItem);
+    Q_EMIT closeEditor(
+        static_cast<QWidget *>(QObject::sender()), QAbstractItemDelegate::EditPreviousItem);
 }
 
 void AttendeeComboBoxDelegate::rightPressed()
 {
-    Q_EMIT closeEditor(static_cast<QWidget *>(QObject::sender()), QAbstractItemDelegate::EditNextItem);
+    Q_EMIT closeEditor(
+        static_cast<QWidget *>(QObject::sender()), QAbstractItemDelegate::EditNextItem);
 }
 
-bool AttendeeComboBoxDelegate::helpEvent(QHelpEvent *event, QAbstractItemView *view,
-        const QStyleOptionViewItem &option, const QModelIndex &index)
+bool AttendeeComboBoxDelegate::helpEvent(QHelpEvent *event, QAbstractItemView *view, const QStyleOptionViewItem &option, const QModelIndex &index)
 {
     if (!event || !view) {
         return false;
     }
     switch (event->type()) {
 #ifndef QT_NO_TOOLTIP
-    case QEvent::ToolTip: {
-        QHelpEvent *he = static_cast<QHelpEvent *>(event);
-        QToolTip::showText(he->globalPos(), mToolTip, view);
+    case QEvent::ToolTip:
+    {
+        QToolTip::showText(event->globalPos(), mToolTip, view);
         return true;
     }
 #endif
 #ifndef QT_NO_WHATSTHIS
     case QEvent::QueryWhatsThis:
         return true;
-    case QEvent::WhatsThis: {
-        QHelpEvent *he = static_cast<QHelpEvent *>(event);
-        QWhatsThis::showText(he->globalPos(), mWhatsThis, view);
+    case QEvent::WhatsThis:
+    {
+        QWhatsThis::showText(event->globalPos(), mWhatsThis, view);
         return true;
     }
 #endif
