@@ -1,25 +1,11 @@
 /*
- *  Copyright (C) 2014 Sandro Knauß <knauss@kolabsys.com>
+ *  SPDX-FileCopyrightText: 2014 Sandro Knauß <knauss@kolabsys.com>
  *
- *  This library is free software; you can redistribute it and/or modify it
- *  under the terms of the GNU Library General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or (at your
- *  option) any later version.
- *
- *  This library is distributed in the hope that it will be useful, but WITHOUT
- *  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
- *  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
- *  License for more details.
- *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to the
- *  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
- *  02110-1301, USA.
+ *  SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #include "attendeetablemodel.h"
 
-#include <KCalCore/Attendee>
 #include <KEmailAddress>
 
 #include <KLocalizedString>
@@ -28,8 +14,6 @@ using namespace IncidenceEditorNG;
 
 AttendeeTableModel::AttendeeTableModel(QObject *parent)
     : QAbstractTableModel(parent)
-    , mKeepEmpty(false)
-    , mRemoveEmptyLines(false)
 {
 }
 
@@ -65,7 +49,7 @@ QVariant AttendeeTableModel::data(const QModelIndex &index, int role) const
         return QVariant();
     }
 
-    const KCalCore::Attendee attendee = mAttendeeList[index.row()];
+    const KCalendarCore::Attendee attendee = mAttendeeList[index.row()];
     if (role == Qt::DisplayRole || role == Qt::EditRole) {
         switch (index.column()) {
         case Role:
@@ -114,10 +98,10 @@ bool AttendeeTableModel::setData(const QModelIndex &index, const QVariant &value
 {
     QString email, name;
     if (index.isValid() && role == Qt::EditRole) {
-        KCalCore::Attendee &attendee = mAttendeeList[index.row()];
+        KCalendarCore::Attendee &attendee = mAttendeeList[index.row()];
         switch (index.column()) {
         case Role:
-            attendee.setRole(static_cast<KCalCore::Attendee::Role>(value.toInt()));
+            attendee.setRole(static_cast<KCalendarCore::Attendee::Role>(value.toInt()));
             break;
         case FullName:
             if (mRemoveEmptyLines && value.toString().trimmed().isEmpty()) {
@@ -138,10 +122,10 @@ bool AttendeeTableModel::setData(const QModelIndex &index, const QVariant &value
             mAttendeeAvailable[index.row()] = static_cast<AvailableStatus>(value.toInt());
             break;
         case Status:
-            attendee.setStatus(static_cast<KCalCore::Attendee::PartStat>(value.toInt()));
+            attendee.setStatus(static_cast<KCalendarCore::Attendee::PartStat>(value.toInt()));
             break;
         case CuType:
-            attendee.setCuType(static_cast<KCalCore::Attendee::CuType>(value.toInt()));
+            attendee.setCuType(static_cast<KCalendarCore::Attendee::CuType>(value.toInt()));
             break;
         case Response:
             attendee.setRSVP(value.toBool());
@@ -191,7 +175,7 @@ bool AttendeeTableModel::insertRows(int position, int rows, const QModelIndex &p
     beginInsertRows(parent, position, position + rows - 1);
 
     for (int row = 0; row < rows; ++row) {
-        KCalCore::Attendee attendee(QLatin1String(""), QLatin1String(""));
+        KCalendarCore::Attendee attendee(QLatin1String(""), QLatin1String(""));
         mAttendeeList.insert(position, attendee);
         mAttendeeAvailable.insert(mAttendeeAvailable.begin() + position, AvailableStatus{});
     }
@@ -213,7 +197,7 @@ bool AttendeeTableModel::removeRows(int position, int rows, const QModelIndex &p
     return true;
 }
 
-bool AttendeeTableModel::insertAttendee(int position, const KCalCore::Attendee &attendee)
+bool AttendeeTableModel::insertAttendee(int position, const KCalendarCore::Attendee &attendee)
 {
     beginInsertRows(QModelIndex(), position, position);
     mAttendeeList.insert(position, attendee);
@@ -225,7 +209,7 @@ bool AttendeeTableModel::insertAttendee(int position, const KCalCore::Attendee &
     return true;
 }
 
-void AttendeeTableModel::setAttendees(const KCalCore::Attendee::List &attendees)
+void AttendeeTableModel::setAttendees(const KCalendarCore::Attendee::List &attendees)
 {
     Q_EMIT layoutAboutToBeChanged();
 
@@ -238,7 +222,7 @@ void AttendeeTableModel::setAttendees(const KCalCore::Attendee::List &attendees)
     Q_EMIT layoutChanged();
 }
 
-KCalCore::Attendee::List AttendeeTableModel::attendees() const
+KCalendarCore::Attendee::List AttendeeTableModel::attendees() const
 {
     return mAttendeeList;
 }
@@ -247,7 +231,7 @@ void AttendeeTableModel::addEmptyAttendee()
 {
     if (mKeepEmpty) {
         bool create = true;
-        for (const KCalCore::Attendee &attendee : qAsConst(mAttendeeList)) {
+        for (const KCalendarCore::Attendee &attendee : qAsConst(mAttendeeList)) {
             if (attendee.fullName().isEmpty()) {
                 create = false;
                 break;
@@ -290,12 +274,12 @@ ResourceFilterProxyModel::ResourceFilterProxyModel(QObject *parent)
 
 bool ResourceFilterProxyModel::filterAcceptsRow(int sourceRow, const QModelIndex &sourceParent) const
 {
-    QModelIndex cuTypeIndex = sourceModel()->index(sourceRow, AttendeeTableModel::CuType,
+    const QModelIndex cuTypeIndex = sourceModel()->index(sourceRow, AttendeeTableModel::CuType,
                                                    sourceParent);
-    KCalCore::Attendee::CuType cuType
-        = static_cast<KCalCore::Attendee::CuType>(sourceModel()->data(cuTypeIndex).toUInt());
+    KCalendarCore::Attendee::CuType cuType
+        = static_cast<KCalendarCore::Attendee::CuType>(sourceModel()->data(cuTypeIndex).toUInt());
 
-    return cuType == KCalCore::Attendee::Resource || cuType == KCalCore::Attendee::Room;
+    return cuType == KCalendarCore::Attendee::Resource || cuType == KCalendarCore::Attendee::Room;
 }
 
 AttendeeFilterProxyModel::AttendeeFilterProxyModel(QObject *parent)
@@ -305,10 +289,10 @@ AttendeeFilterProxyModel::AttendeeFilterProxyModel(QObject *parent)
 
 bool AttendeeFilterProxyModel::filterAcceptsRow(int sourceRow, const QModelIndex &sourceParent) const
 {
-    QModelIndex cuTypeIndex = sourceModel()->index(sourceRow, AttendeeTableModel::CuType,
+    const QModelIndex cuTypeIndex = sourceModel()->index(sourceRow, AttendeeTableModel::CuType,
                                                    sourceParent);
-    KCalCore::Attendee::CuType cuType
-        = static_cast<KCalCore::Attendee::CuType>(sourceModel()->data(cuTypeIndex).toUInt());
+    KCalendarCore::Attendee::CuType cuType
+        = static_cast<KCalendarCore::Attendee::CuType>(sourceModel()->data(cuTypeIndex).toUInt());
 
-    return !(cuType == KCalCore::Attendee::Resource || cuType == KCalCore::Attendee::Room);
+    return !(cuType == KCalendarCore::Attendee::Resource || cuType == KCalendarCore::Attendee::Room);
 }
