@@ -1,26 +1,13 @@
 /*
- *  Copyright (C) 2014 Sandro Knauß <knauss@kolabsys.com>
+ *  SPDX-FileCopyrightText: 2014 Sandro Knauß <knauss@kolabsys.com>
  *
- *  This library is free software; you can redistribute it and/or modify it
- *  under the terms of the GNU Library General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or (at your
- *  option) any later version.
- *
- *  This library is distributed in the hope that it will be useful, but WITHOUT
- *  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
- *  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
- *  License for more details.
- *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to the
- *  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
- *  02110-1301, USA.
+ *  SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #ifndef INCIDENCEEDITOR_ATTENDEETABLEMODEL_H
 #define INCIDENCEEDITOR_ATTENDEETABLEMODEL_H
 
-#include <KCalCore/Attendee>
+#include <KCalendarCore/Attendee>
 
 #include <QAbstractTableModel>
 #include <QSortFilterProxyModel>
@@ -68,10 +55,10 @@ public:
     Q_REQUIRED_RESULT bool insertRows(int position, int rows, const QModelIndex &index = QModelIndex()) override;
     Q_REQUIRED_RESULT bool removeRows(int position, int rows, const QModelIndex &index = QModelIndex()) override;
 
-    Q_REQUIRED_RESULT bool insertAttendee(int position, const KCalCore::Attendee &attendee);
+    Q_REQUIRED_RESULT bool insertAttendee(int position, const KCalendarCore::Attendee &attendee);
 
-    void setAttendees(const KCalCore::Attendee::List &resources);
-    Q_REQUIRED_RESULT KCalCore::Attendee::List attendees() const;
+    void setAttendees(const KCalendarCore::Attendee::List &resources);
+    Q_REQUIRED_RESULT KCalendarCore::Attendee::List attendees() const;
 
     void setKeepEmpty(bool keepEmpty);
     Q_REQUIRED_RESULT bool keepEmpty() const;
@@ -81,10 +68,10 @@ public:
 private:
     void addEmptyAttendee();
 
-    KCalCore::Attendee::List mAttendeeList;
+    KCalendarCore::Attendee::List mAttendeeList;
     std::vector<AvailableStatus> mAttendeeAvailable;
-    bool mKeepEmpty;
-    bool mRemoveEmptyLines;
+    bool mKeepEmpty = false;
+    bool mRemoveEmptyLines = false;
 };
 
 class ResourceFilterProxyModel : public QSortFilterProxyModel
