@@ -1,21 +1,8 @@
 /*
-  Copyright (c) 2010 Bertjan Broeksema <broeksema@kde.org>
-  Copyright (c) 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
+  SPDX-FileCopyrightText: 2010 Bertjan Broeksema <broeksema@kde.org>
+  SPDX-FileCopyrightText: 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef INCIDENCEEDITOR_INCIDENCEDATETIME_H
@@ -23,9 +10,9 @@
 
 #include "incidenceeditor-ng.h"
 
-#include <KCalCore/Event>
-#include <KCalCore/Journal>
-#include <KCalCore/Todo>
+#include <KCalendarCore/Event>
+#include <KCalendarCore/Journal>
+#include <KCalendarCore/Todo>
 
 #include <QDate>
 
@@ -43,8 +30,8 @@ public:
     explicit IncidenceDateTime(Ui::EventOrTodoDesktop *ui);
     ~IncidenceDateTime() override;
 
-    void load(const KCalCore::Incidence::Ptr &incidence) override;
-    void save(const KCalCore::Incidence::Ptr &incidence) override;
+    void load(const KCalendarCore::Incidence::Ptr &incidence) override;
+    void save(const KCalendarCore::Incidence::Ptr &incidence) override;
     Q_REQUIRED_RESULT bool isDirty() const override;
 
     /**
@@ -69,6 +56,8 @@ public:
     Q_REQUIRED_RESULT bool startDateTimeEnabled() const;
     Q_REQUIRED_RESULT bool endDateTimeEnabled() const;
 
+    void focusInvalidField() override;
+
     Q_REQUIRED_RESULT bool isValid() const override;
     void printDebugInfo() const override;
 
@@ -102,20 +91,20 @@ private Q_SLOTS: /// Todo specific
     void enableTimeEdits();
 
 private:
-    bool isDirty(const KCalCore::Todo::Ptr &todo) const;
-    bool isDirty(const KCalCore::Event::Ptr &event) const;
-    bool isDirty(const KCalCore::Journal::Ptr &journal) const;
+    bool isDirty(const KCalendarCore::Todo::Ptr &todo) const;
+    bool isDirty(const KCalendarCore::Event::Ptr &event) const;
+    bool isDirty(const KCalendarCore::Journal::Ptr &journal) const;
 
 protected:
     bool eventFilter(QObject *obj, QEvent *event) override;
 
 private:
-    void load(const KCalCore::Event::Ptr &event, bool isTemplate = false, bool templateOverridesTimes = false);
-    void load(const KCalCore::Todo::Ptr &todo, bool isTemplate = false, bool templateOverridesTimes = false);
-    void load(const KCalCore::Journal::Ptr &journal, bool isTemplate = false, bool templateOverridesTimes = false);
-    void save(const KCalCore::Event::Ptr &event);
-    void save(const KCalCore::Todo::Ptr &todo);
-    void save(const KCalCore::Journal::Ptr &journal);
+    void load(const KCalendarCore::Event::Ptr &event, bool isTemplate = false, bool templateOverridesTimes = false);
+    void load(const KCalendarCore::Todo::Ptr &todo, bool isTemplate = false, bool templateOverridesTimes = false);
+    void load(const KCalendarCore::Journal::Ptr &journal, bool isTemplate = false, bool templateOverridesTimes = false);
+    void save(const KCalendarCore::Event::Ptr &event);
+    void save(const KCalendarCore::Todo::Ptr &todo);
+    void save(const KCalendarCore::Journal::Ptr &journal);
     void setDateTimes(const QDateTime &start, const QDateTime &end);
     void setTimes(const QDateTime &start, const QDateTime &end);
     void setTimeZoneLabelEnabled(bool enable);
