@@ -1,21 +1,8 @@
 /*
-  Copyright (c) 2010 Bertjan Broeksema <broeksema@kde.org>
-  Copyright (C) 2010 Klaralvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
+  SPDX-FileCopyrightText: 2010 Bertjan Broeksema <broeksema@kde.org>
+  SPDX-FileCopyrightText: 2010 Klaralvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "incidencerecurrence.h"
@@ -23,7 +10,6 @@
 #include "ui_dialogdesktop.h"
 
 #include "incidenceeditor_debug.h"
-#include <KLocalizedString>
 #include <QLocale>
 
 using namespace IncidenceEditorNG;
@@ -189,9 +175,9 @@ void IncidenceRecurrence::load(const KCalendarCore::Incidence::Ptr &incidence)
     {
         mUi->mRecurrenceTypeCombo->setCurrentIndex(RecurrenceTypeWeekly);
         handleRecurrenceTypeChange(RecurrenceTypeWeekly);
-        QBitArray disableDays(7 /*size*/, 0 /*default value*/);
+        QBitArray disableDays(7 /*size*/, false /*default value*/);
         // dayOfWeek returns between 1 and 7
-        disableDays.setBit(currentDate().dayOfWeek() - 1, 1);
+        disableDays.setBit(currentDate().dayOfWeek() - 1, true);
         mUi->mWeekDayCombo->setDays(r->days(), disableDays);
         setFrequency(f);
         break;
@@ -412,6 +398,18 @@ bool IncidenceRecurrence::isDirty() const
     return false;
 }
 
+void IncidenceRecurrence::focusInvalidField()
+{
+    KCalendarCore::Incidence::Ptr incidence(mLoadedIncidence->clone());
+    writeToIncidence(incidence);
+    if (incidence->recurs()) {
+        if (mUi->mRecurrenceEndCombo->currentIndex() == RecurrenceEndOn
+            && !mUi->mRecurrenceEndDate->date().isValid()) {
+            mUi->mRecurrenceEndDate->setFocus();
+        }
+    }
+}
+
 bool IncidenceRecurrence::isValid() const
 {
     mLastErrorString.clear();
@@ -449,7 +447,8 @@ bool IncidenceRecurrence::isValid() const
 
         if (mUi->mRecurrenceEndCombo->currentIndex() == RecurrenceEndOn
             && !mUi->mRecurrenceEndDate->date().isValid()) {
-            qCWarning(INCIDENCEEDITOR_LOG) << "Recurrence end date is invalid."; // TODO: strings after freeze
+            mLastErrorString = i18nc("@info", "The recurrence end date is invalid.");
+            qCDebug(INCIDENCEEDITOR_LOG) << mLastErrorString;
             return false;
         }
     }
@@ -859,10 +858,10 @@ void IncidenceRecurrence::setDefaults()
     // -1 because we want between 0 and 6
     const int day = currentDate().dayOfWeek() - 1;
 
-    QBitArray checkDays(7, 0);
+    QBitArray checkDays(7, false);
     checkDays.setBit(day);
 
-    QBitArray disableDays(7, 0);
+    QBitArray disableDays(7, false);
     disableDays.setBit(day);
 
     mUi->mWeekDayCombo->setDays(checkDays, disableDays);
