@@ -1,23 +1,7 @@
 /*
- * Copyright (c) 2014 Sandro Knauß <knauss@kolabsys.com>
+ * SPDX-FileCopyrightText: 2014 Sandro Knauß <knauss@kolabsys.com>
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License along
- * with this program; if not, write to the Free Software Foundation, Inc.,
- * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
- *
- * As a special exception, permission is given to link this program
- * with any edition of Qt, and distribute the resulting executable,
- * without including the source code for Qt in the source distribution.
+ * SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
  */
 
 #include "individualmailcomponentfactory.h"
@@ -40,15 +24,20 @@ IndividualMessageQueueJob::IndividualMessageQueueJob(const KIdentityManagement::
     , mUpdate(update)
     , mEdit(edit)
     , mIdentity(identity)
-    , mQueueJob(nullptr)
-    , mComposerJob(nullptr)
 {
 }
 
 void IndividualMessageQueueJob::start()
 {
+#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
+    const auto to = addressAttribute().to();
+    QSet<QString> attendeesTo(to.begin(), to.end());
+    const auto cc = addressAttribute().cc();
+    QSet<QString> attendeesCc(cc.begin(), cc.end());
+#else
     QSet<QString> attendeesTo(QSet<QString>::fromList(addressAttribute().to()));
     QSet<QString> attendeesCc(QSet<QString>::fromList(addressAttribute().cc()));
+#endif
 
     QStringList attendeesAutoTo, attendeesAutoCc;
     for (const KCalendarCore::Attendee &attendee : qAsConst(mUpdate)) {
@@ -86,8 +75,8 @@ void IndividualMessageQueueJob::start()
 void IndividualMessageQueueJob::startQueueJob(const QStringList &messageTo, const QStringList &to, const QStringList &messageCc, const QStringList &cc)
 {
     KMime::Message::Ptr msg(message());
-    msg->to()->fromUnicodeString(messageTo.join(QStringLiteral(", ")), "utf-8");
-    msg->cc()->fromUnicodeString(messageCc.join(QStringLiteral(", ")), "utf-8");
+    msg->to()->fromUnicodeString(messageTo.join(QLatin1String(", ")), "utf-8");
+    msg->cc()->fromUnicodeString(messageCc.join(QLatin1String(", ")), "utf-8");
     msg->assemble();
 
     mQueueJob = new MailTransport::MessageQueueJob(this);
@@ -119,8 +108,8 @@ void IndividualMessageQueueJob::startQueueJob(const QStringList &messageTo, cons
 void IndividualMessageQueueJob::startComposerJob(const QStringList &to, const QStringList &cc)
 {
     mComposerJob
-        = new OpenComposerJob(this, to.join(QStringLiteral(", ")), cc.join(QStringLiteral(
-                                                                               ", ")),
+        = new OpenComposerJob(this, to.join(QLatin1String(", ")), cc.join(QLatin1String(
+                                                                              ", ")),
                               QString(), message(), mIdentity);
     connect(mComposerJob, &OpenComposerJob::finished, this,
             &IndividualMessageQueueJob::handleJobFinished);
@@ -254,7 +243,7 @@ MailTransport::MessageQueueJob *IndividualMailComponentFactory::createMessageQue
 Akonadi::ITIPHandlerDialogDelegate *IndividualMailComponentFactory::createITIPHanderDialogDelegate(
     const KCalendarCore::Incidence::Ptr &incidence, KCalendarCore::iTIPMethod method, QWidget *parent)
 {
-    IndividualMailITIPHandlerDialogDelegate *askDelegator
+    auto *askDelegator
         = new IndividualMailITIPHandlerDialogDelegate(incidence, method, parent);
     connect(askDelegator, &IndividualMailITIPHandlerDialogDelegate::setEdit, this,
             &IndividualMailComponentFactory::onSetEdit);
