@@ -1,30 +1,13 @@
 /*
- * Copyright (c) 2014 Sandro Knauß <knauss@kolabsys.com>
+ * SPDX-FileCopyrightText: 2014 Sandro Knauß <knauss@kolabsys.com>
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License along
- * with this program; if not, write to the Free Software Foundation, Inc.,
- * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
- *
- * As a special exception, permission is given to link this program
- * with any edition of Qt, and distribute the resulting executable,
- * without including the source code for Qt in the source distribution.
+ * SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
  */
 
 #include "resourcemanagement.h"
 #include "ui_resourcemanagement.h"
 #include "resourcemodel.h"
-#include "CalendarSupport/FreeBusyItem"
-#include "CalendarSupport/FreeBusyCalendar"
+#include <CalendarSupport/FreeBusyItem>
 #include "ldaputils.h"
 
 #include "freebusyganttproxymodel.h"
@@ -32,7 +15,6 @@
 #include <Akonadi/Calendar/FreeBusyManager>
 
 #include <EventViews/AgendaView>
-#include <EventViews/ViewCalendar>
 
 #include <KCalendarCore/Event>
 #include <KCalendarCore/MemoryCalendar>
@@ -130,7 +112,7 @@ ResourceManagement::ResourceManagement(QWidget *parent)
 
     QWidget *w = new QWidget(this);
     mUi->setupUi(w);
-    QVBoxLayout *mainLayout = new QVBoxLayout(this);
+    auto *mainLayout = new QVBoxLayout(this);
     mainLayout->addWidget(w);
 
     mainLayout->addWidget(buttonBox);
@@ -140,7 +122,7 @@ ResourceManagement::ResourceManagement(QWidget *parent)
 
     mAgendaView = new EventViews::AgendaView(QDate(), QDate(), false, false);
 
-    FreebusyViewCalendar *fbCalendar = new FreebusyViewCalendar();
+    auto *fbCalendar = new FreebusyViewCalendar();
     fbCalendar->mCalendar = mFreebusyCalendar.calendar();
     mFbCalendar = EventViews::ViewCalendar::Ptr(fbCalendar);
     mAgendaView->addCalendar(mFbCalendar);
@@ -151,7 +133,7 @@ ResourceManagement::ResourceManagement(QWidget *parent)
     attrs << QStringLiteral("cn") << QStringLiteral("mail")
           << QStringLiteral("owner") << QStringLiteral("givenname") << QStringLiteral("sn")
           << QStringLiteral("kolabDescAttribute") << QStringLiteral("description");
-    ResourceModel *resourcemodel = new ResourceModel(attrs);
+    auto *resourcemodel = new ResourceModel(attrs, this);
     mUi->treeResults->setModel(resourcemodel);
 
     // This doesn't work till now :(-> that's why i use the click signal
