@@ -1,21 +1,7 @@
 /*
- * Copyright 2014  Sandro Knauß <knauss@kolabsys.com>
+ * SPDX-FileCopyrightText: 2014 Sandro Knauß <knauss@kolabsys.com>
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License or (at your option) version 3 or any later version
- * accepted by the membership of KDE e.V. (or its successor approved
- * by the membership of KDE e.V.), which shall act as a proxy
- * defined in Section 14 of version 3 of the license.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  *
  */
 #include "resourcemodel.h"
@@ -28,7 +14,6 @@ using namespace IncidenceEditorNG;
 
 ResourceModel::ResourceModel(const QStringList &headers, QObject *parent)
     : QAbstractItemModel(parent)
-    , foundCollection(false)
 {
     this->headers = headers;
     rootItem = ResourceItem::Ptr(new ResourceItem(KLDAP::LdapDN(), headers, KLDAP::LdapClient(0)));
@@ -93,7 +78,7 @@ Qt::ItemFlags ResourceModel::flags(const QModelIndex &index) const
 ResourceItem *ResourceModel::getItem(const QModelIndex &index) const
 {
     if (index.isValid()) {
-        ResourceItem *item = static_cast<ResourceItem *>(index.internalPointer());
+        auto *item = static_cast<ResourceItem *>(index.internalPointer());
         if (item) {
             return item;
         }
